==> apache-mailet-base-3.0.1-sources.jar: org/apache/mailet/base/MailetPipelineLogging.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.mailet.base;

import org.apache.mailet.Mail;
import org.apache.mailet.Mailet;
import org.apache.mailet.MailetConfig;
import org.apache.mailet.MailetContext;
import org.slf4j.Logger;

import com.google.common.base.Function;
import com.google.common.base.Optional;

public class MailetPipelineLogging {

    public static void logBeginOfMailetProcess(final Mailet mailet, final Mail mail) {
        getLogger(mailet)
        .transform(new Function<Logger, Boolean>() {

            @Override
            public Boolean apply(Logger logger) {
                logger.debug("Entering mailet: {}\n\tmail state {}", mailet.getMailetInfo(), mail.getState());
                return true;
            }
        });
    }

    public static void logEndOfMailetProcess(final Mailet mailet, final Mail mail) {
        getLogger(mailet)
            .transform(new Function<Logger, Boolean>() {

                @Override
                public Boolean apply(Logger logger) {
                    logger.debug("End of mailet: {}\n\tmail state {}", mailet.getMailetInfo(), mail.getState());
                    return true;
                }
            });
    }

    private static Optional<Logger> getLogger(Mailet mailet) {
        MailetConfig mailetConfig = mailet.getMailetConfig();
        if (mailetConfig == null) {
            return Optional.absent();
        }
        MailetContext mailetContext = mailetConfig.getMailetContext();
        if (mailetContext == null) {
            return Optional.absent();
        }
        return Optional.fromNullable(mailetContext.getLogger());
    }
}

==> apache-mailet-base-3.9.0-sources.jar: org/apache/mailet/base/MailetPipelineLogging.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.mailet.base;

import java.util.Optional;

import org.apache.mailet.Mail;
import org.apache.mailet.Mailet;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.annotations.VisibleForTesting;
import com.google.common.base.Strings;

public class MailetPipelineLogging {
    private static final Logger LOGGER = LoggerFactory.getLogger(MailetPipelineLogging.class);

    public static void logBeginOfMailetProcess(Mailet mailet, Mail mail) {
        LOGGER.debug("Mail: {} Entering mailet: {}", mail.getState(), getMailetInfo(mailet));
    }


    public static void logEndOfMailetProcess(Mailet mailet, Mail mail) {
        LOGGER.debug("Mail: {} End of mailet: {}", mail.getState(), getMailetInfo(mailet));
    }

    @VisibleForTesting
    static String getMailetInfo(Mailet mailet) {
        return Optional.ofNullable(Strings.emptyToNull(mailet.getMailetInfo()))
                    .orElse(mailet.getClass().getSimpleName());
    }
}
